@@ -16,8 +16,9 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include "misc/charuty.h"
 #include "orzcharlist.h"
+#include "orzcharset.h"
+#include "misc/charuty.h"
 #include <gdk/gdkkeysyms.h>
 
 
@@ -530,12 +531,12 @@ orz_charlist_set_charlist (OrzCharlist *charlist,
 /*  ja:文字符号化方式を取得する
     charlist,ウィジェット
          RET,文字符号化方式                                                 */
-/*gchar *
+gchar *
 orz_charlist_get_charset (OrzCharlist *charlist)
 {
   return charlist ? orz_charset_get_charset (ORZ_CHARSET (charlist->charset))
                   : NULL;
-}*/
+}
 
 
 /*  ja:文字符号化方式を設定する
@@ -555,12 +556,12 @@ orz_charlist_set_charset (OrzCharlist *charlist,
 /*  ja:文字符号化方式の候補を取得する
     charlist,ウィジェット
          RET,文字符号化方式の候補                                           */
-/*gchar *
+gchar *
 orz_charlist_get_candidate (OrzCharlist *charlist)
 {
   return charlist
         ? orz_charset_get_candidate (ORZ_CHARSET (charlist->charset)) : NULL;
-}*/
+}
 
 
 /*  ja:文字符号化方式の候補を追加する
@@ -608,10 +609,10 @@ orz_charlist_add_candidate (OrzCharlist *charlist,
      charlist,ウィジェット
     candidate,文字符号化方式のリスト,NULL:すべて削除
           RET,TRUE:正常終了,FALSE:エラー                                    */
-/*gboolean
+gboolean
 orz_charlist_remove_candidate (OrzCharlist *charlist,
                                const gchar *candidate)
 {
   return charlist ? orz_charset_remove_candidate
                         (ORZ_CHARSET (charlist->charset), candidate) : FALSE;
-}*/
+}
