@@ -48,12 +48,17 @@ add_dialog_clicked (GtkWidget *widget,
 #if GTK_CHECK_VERSION(2,4,0)
   dialog = gtk_file_chooser_dialog_new (_("Browse"),
                     GTK_WINDOW (adddlg->dialog), GTK_FILE_CHOOSER_ACTION_OPEN,
+#ifdef G_OS_WIN32
+                    GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#else /* not G_OS_WIN32 */
                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                     GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+#endif /* not G_OS_WIN32 */
                     NULL);
   file = g_filename_from_utf8 (gtk_entry_get_text (GTK_ENTRY (adddlg->entry)),
                                                         -1, NULL, NULL, NULL);
-  if (fileio_isfile (file))
+  if (g_file_test (file, G_FILE_TEST_EXISTS))
     {
       gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), file);
     }
@@ -64,7 +69,7 @@ add_dialog_clicked (GtkWidget *widget,
       dir = g_path_get_dirname (file);
       path = fileio_get_full_path (dir);
       g_free (dir);
-      if (fileio_isfile (path))
+      if (g_file_test (path, G_FILE_TEST_EXISTS))
         gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), path);
       g_free (path);
     }
@@ -164,8 +169,13 @@ add_dialog (MmaidWindow *mmaid)
                             (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+#ifdef G_OS_WIN32
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#else /* not G_OS_WIN32 */
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK, GTK_RESPONSE_OK,
+#endif /* not G_OS_WIN32 */
                             NULL);
   g_free (title);
   g_signal_connect (G_OBJECT (adddlg.dialog), "key-press-event",
