@@ -68,8 +68,13 @@ command_open (GtkWidget *widget,
 #if GTK_CHECK_VERSION(2,4,0)
   dialog = gtk_file_chooser_dialog_new (title,
                         GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_OPEN,
+# ifdef G_OS_WIN32
+                        GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+# else /* not G_OS_WIN32 */
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                         GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+# endif /* not G_OS_WIN32 */
                         NULL);
   if (open_path)
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), open_path);
@@ -158,7 +163,7 @@ command_save (GtkWidget *widget,
     {
       gboolean result = TRUE;
 
-      if (fileio_isfile (file))
+      if (g_file_test (file, G_FILE_TEST_EXISTS))
         {
           gchar *utf8str;
           GtkWidget *dialog;
@@ -349,8 +354,13 @@ command_saveas (GtkWidget *widget,
 #if GTK_CHECK_VERSION(2,4,0)
   dialog = gtk_file_chooser_dialog_new (title,
                         GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_SAVE,
+# ifdef G_OS_WIN32
+                        GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
+                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+# else /* not G_OS_WIN32 */
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                         GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
+# endif /* not G_OS_WIN32 */
                         NULL);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   dialog = gtk_file_selection_new (title);
@@ -523,7 +533,7 @@ command_saveas (GtkWidget *widget,
     {
       gboolean result = TRUE;
 
-      if (fileio_isfile (file))
+      if (g_file_test (file, G_FILE_TEST_EXISTS))
         {
           gchar *utf8str;
 
@@ -1101,8 +1111,13 @@ command_search (GtkWidget *widget,
   dialog = gtk_file_chooser_dialog_new (_("Browse"),
                         GTK_WINDOW (window),
                         GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+# ifdef G_OS_WIN32
+                        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+# else /* not G_OS_WIN32 */
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+# endif /* not G_OS_WIN32 */
                         NULL);
   if (path)
     {
