@@ -98,7 +98,7 @@ MiscCreateMenuEntry menu_entries[] = {
 {"/tag/delete",         GTK_STOCK_DELETE,          "Delete",          NULL,             MISC_CREATE_MENU_STOCK,                             command_delete,  NULL, NULL},
 {"/tag/sep3",           NULL,                      NULL,              NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
 #if GTK_CHECK_VERSION(2,10,0)
-{"/tag/all",            GTK_STOCK_SELECT_ALL,      "<control>A",      NULL,             MISC_CREATE_MENU_ITEM,                              command_all,     NULL, NULL},
+{"/tag/all",            GTK_STOCK_SELECT_ALL,      "<control>A",      NULL,             MISC_CREATE_MENU_STOCK,                             command_all,     NULL, NULL},
 #else /* not GTK_CHECK_VERSION(2,10,0) */
 {"/tag/all",            N_("_All"),                "<control>A",      select_all16_xpm, MISC_CREATE_MENU_ITEM,                              command_all,     NULL, NULL},
 #endif /* not GTK_CHECK_VERSION(2,10,0) */
@@ -134,7 +134,7 @@ MiscCreateMenuEntry popup_entries[] = {
 {"/delete",             GTK_STOCK_DELETE,          "Delete",          NULL,             MISC_CREATE_MENU_STOCK,                             command_delete,  NULL, NULL},
 {"/sep2",               NULL,                      NULL,              NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
 #if GTK_CHECK_VERSION(2,10,0)
-{"/all",                GTK_STOCK_SELECT_ALL,      "<control>A",      NULL,             MISC_CREATE_MENU_ITEM,                              command_all,     NULL, NULL},
+{"/all",                GTK_STOCK_SELECT_ALL,      "<control>A",      NULL,             MISC_CREATE_MENU_STOCK,                             command_all,     NULL, NULL},
 #else /* not GTK_CHECK_VERSION(2,10,0) */
 {"/all",                N_("_All"),                "<control>A",      select_all16_xpm, MISC_CREATE_MENU_ITEM,                              command_all,     NULL, NULL},
 #endif /* not GTK_CHECK_VERSION(2,10,0) */
